##  Canceling a Synchronization Run
To cancel a synchronization run in progress, make a POST request to the following endpoint:

```
https://{SUBDOMAIN}.leanix.net/services/integration-api/v1/synchronizationRuns/runId/stop
```



